@@ -53,5 +53,17 @@ def test_check_for_compiler_warnings() -> None:
     assert san.check_for_compiler_warnings(p2).check_warnings_failed
 
 
+def test_sanitizer() -> None:
+    clang = find_clang()
+    assert clang, "Could not find a clang executable"
+    san = Sanitizer(clang=clang)
+    p = SourceProgram(
+        code="int main(){ int a[1] = {0}; return a[1];}", language=Language.C
+    )
+    assert san.check_for_ub_and_address_sanitizer_errors(
+        p, debug=True
+    ).ub_address_sanitizer_failed
+
+
 if __name__ == "__main__":
     test_check_for_compiler_warnings()
